# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["LoginResponse", "AuthTokens"]


class AuthTokens(BaseModel):
    access_token: str = FieldInfo(alias="accessToken")

    refresh_token: str = FieldInfo(alias="refreshToken")


class LoginResponse(BaseModel):
    auth_tokens: Optional[AuthTokens] = FieldInfo(alias="authTokens", default=None)

    message: Optional[str] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AipicExoticOptionsParams"]


class AipicExoticOptionsParams(TypedDict, total=False):
    pet_profile_id: int
    """宠物档案 id"""

    question: str
    """问题"""

    session_id: str
    """会话 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .pet_profile import PetProfile

__all__ = ["PetProfileListResponse"]


class PetProfileListResponse(BaseModel):
    data: Optional[List[PetProfile]] = None

    message: Optional[str] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .._types import FileTypes

__all__ = ["UploadCreateParams"]


class UploadCreateParams(TypedDict, total=False):
    image: Required[FileTypes]
    """要上传的图片文件"""

    is_to_cloud: int
    """是否上传到图床"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import evaluation_put_evaluation_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["EvaluationResource", "AsyncEvaluationResource"]


class EvaluationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EvaluationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return EvaluationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return EvaluationResourceWithStreamingResponse(self)

    def put_evaluation(
        self,
        *,
        content: str,
        evaluation: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        修改评价

        Args:
          content: 文本内容

          evaluation: 评价 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/evaluation/put_evaluation",
            body=maybe_transform(
                {
                    "content": content,
                    "evaluation": evaluation,
                    "session_id": session_id,
                },
                evaluation_put_evaluation_params.EvaluationPutEvaluationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncEvaluationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEvaluationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncEvaluationResourceWithStreamingResponse(self)

    async def put_evaluation(
        self,
        *,
        content: str,
        evaluation: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        修改评价

        Args:
          content: 文本内容

          evaluation: 评价 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/evaluation/put_evaluation",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "evaluation": evaluation,
                    "session_id": session_id,
                },
                evaluation_put_evaluation_params.EvaluationPutEvaluationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class EvaluationResourceWithRawResponse:
    def __init__(self, evaluation: EvaluationResource) -> None:
        self._evaluation = evaluation

        self.put_evaluation = to_raw_response_wrapper(
            evaluation.put_evaluation,
        )


class AsyncEvaluationResourceWithRawResponse:
    def __init__(self, evaluation: AsyncEvaluationResource) -> None:
        self._evaluation = evaluation

        self.put_evaluation = async_to_raw_response_wrapper(
            evaluation.put_evaluation,
        )


class EvaluationResourceWithStreamingResponse:
    def __init__(self, evaluation: EvaluationResource) -> None:
        self._evaluation = evaluation

        self.put_evaluation = to_streamed_response_wrapper(
            evaluation.put_evaluation,
        )


class AsyncEvaluationResourceWithStreamingResponse:
    def __init__(self, evaluation: AsyncEvaluationResource) -> None:
        self._evaluation = evaluation

        self.put_evaluation = async_to_streamed_response_wrapper(
            evaluation.put_evaluation,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["PetProfileCreateParams"]


class PetProfileCreateParams(TypedDict, total=False):
    allergy_history: Optional[str]
    """过敏史"""

    avatar: Optional[str]
    """头像"""

    birthday: str
    """生日"""

    disease_history: Optional[str]
    """疾病史"""

    family_history: Optional[str]
    """家族史"""

    gender: int
    """性别 1-公 2-母"""

    is_neutered: Optional[int]
    """是否已绝育 0-否 1-是"""

    is_vaccination: int
    """是否已接种疫苗 0-否 1-是"""

    name: str
    """宠物名字"""

    pet_type: int
    """宠物类型"""

    pet_variety: Optional[str]
    """宠物品种"""

    vaccination_date: Optional[str]
    """疫苗时间"""

    weight: Optional[str]
    """重量"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAipic:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_options(self, client: Czlai) -> None:
        aipic = client.aipic.options()
        assert aipic is None

    @parametrize
    def test_method_options_with_all_params(self, client: Czlai) -> None:
        aipic = client.aipic.options(
            pet_profile_id=0,
            question="question",
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    def test_raw_response_options(self, client: Czlai) -> None:
        response = client.aipic.with_raw_response.options()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = response.parse()
        assert aipic is None

    @parametrize
    def test_streaming_response_options(self, client: Czlai) -> None:
        with client.aipic.with_streaming_response.options() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_pic_result(self, client: Czlai) -> None:
        aipic = client.aipic.pic_result()
        assert aipic is None

    @parametrize
    def test_method_pic_result_with_all_params(self, client: Czlai) -> None:
        aipic = client.aipic.pic_result(
            img_belong=0,
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    def test_raw_response_pic_result(self, client: Czlai) -> None:
        response = client.aipic.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = response.parse()
        assert aipic is None

    @parametrize
    def test_streaming_response_pic_result(self, client: Czlai) -> None:
        with client.aipic.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_question(self, client: Czlai) -> None:
        aipic = client.aipic.question()
        assert aipic is None

    @parametrize
    def test_method_question_with_all_params(self, client: Czlai) -> None:
        aipic = client.aipic.question(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    def test_raw_response_question(self, client: Czlai) -> None:
        response = client.aipic.with_raw_response.question()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = response.parse()
        assert aipic is None

    @parametrize
    def test_streaming_response_question(self, client: Czlai) -> None:
        with client.aipic.with_streaming_response.question() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report(self, client: Czlai) -> None:
        aipic = client.aipic.report(
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    def test_method_report_with_all_params(self, client: Czlai) -> None:
        aipic = client.aipic.report(
            session_id="session_id",
            img_url="img_url",
            pet_profile_id=0,
            sub_module_type=0,
        )
        assert aipic is None

    @parametrize
    def test_raw_response_report(self, client: Czlai) -> None:
        response = client.aipic.with_raw_response.report(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = response.parse()
        assert aipic is None

    @parametrize
    def test_streaming_response_report(self, client: Czlai) -> None:
        with client.aipic.with_streaming_response.report(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report_task(self, client: Czlai) -> None:
        aipic = client.aipic.report_task(
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    def test_method_report_task_with_all_params(self, client: Czlai) -> None:
        aipic = client.aipic.report_task(
            session_id="session_id",
            img_url="img_url",
            report_type=0,
        )
        assert aipic is None

    @parametrize
    def test_raw_response_report_task(self, client: Czlai) -> None:
        response = client.aipic.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = response.parse()
        assert aipic is None

    @parametrize
    def test_streaming_response_report_task(self, client: Czlai) -> None:
        with client.aipic.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_validate(self, client: Czlai) -> None:
        aipic = client.aipic.validate()
        assert aipic is None

    @parametrize
    def test_method_validate_with_all_params(self, client: Czlai) -> None:
        aipic = client.aipic.validate(
            answer="answer",
            pet_profile_id=0,
            question="question",
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    def test_raw_response_validate(self, client: Czlai) -> None:
        response = client.aipic.with_raw_response.validate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = response.parse()
        assert aipic is None

    @parametrize
    def test_streaming_response_validate(self, client: Czlai) -> None:
        with client.aipic.with_streaming_response.validate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True


class TestAsyncAipic:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_options(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.options()
        assert aipic is None

    @parametrize
    async def test_method_options_with_all_params(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.options(
            pet_profile_id=0,
            question="question",
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    async def test_raw_response_options(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aipic.with_raw_response.options()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = await response.parse()
        assert aipic is None

    @parametrize
    async def test_streaming_response_options(self, async_client: AsyncCzlai) -> None:
        async with async_client.aipic.with_streaming_response.options() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = await response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_pic_result(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.pic_result()
        assert aipic is None

    @parametrize
    async def test_method_pic_result_with_all_params(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.pic_result(
            img_belong=0,
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    async def test_raw_response_pic_result(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aipic.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = await response.parse()
        assert aipic is None

    @parametrize
    async def test_streaming_response_pic_result(self, async_client: AsyncCzlai) -> None:
        async with async_client.aipic.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = await response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_question(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.question()
        assert aipic is None

    @parametrize
    async def test_method_question_with_all_params(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.question(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    async def test_raw_response_question(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aipic.with_raw_response.question()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = await response.parse()
        assert aipic is None

    @parametrize
    async def test_streaming_response_question(self, async_client: AsyncCzlai) -> None:
        async with async_client.aipic.with_streaming_response.question() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = await response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.report(
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    async def test_method_report_with_all_params(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.report(
            session_id="session_id",
            img_url="img_url",
            pet_profile_id=0,
            sub_module_type=0,
        )
        assert aipic is None

    @parametrize
    async def test_raw_response_report(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aipic.with_raw_response.report(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = await response.parse()
        assert aipic is None

    @parametrize
    async def test_streaming_response_report(self, async_client: AsyncCzlai) -> None:
        async with async_client.aipic.with_streaming_response.report(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = await response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report_task(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.report_task(
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    async def test_method_report_task_with_all_params(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.report_task(
            session_id="session_id",
            img_url="img_url",
            report_type=0,
        )
        assert aipic is None

    @parametrize
    async def test_raw_response_report_task(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aipic.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = await response.parse()
        assert aipic is None

    @parametrize
    async def test_streaming_response_report_task(self, async_client: AsyncCzlai) -> None:
        async with async_client.aipic.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = await response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_validate(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.validate()
        assert aipic is None

    @parametrize
    async def test_method_validate_with_all_params(self, async_client: AsyncCzlai) -> None:
        aipic = await async_client.aipic.validate(
            answer="answer",
            pet_profile_id=0,
            question="question",
            session_id="session_id",
        )
        assert aipic is None

    @parametrize
    async def test_raw_response_validate(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aipic.with_raw_response.validate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aipic = await response.parse()
        assert aipic is None

    @parametrize
    async def test_streaming_response_validate(self, async_client: AsyncCzlai) -> None:
        async with async_client.aipic.with_streaming_response.validate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aipic = await response.parse()
            assert aipic is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["PointPriceRetrieveResponse", "Data"]


class Data(BaseModel):
    is_module_item: Optional[int] = None
    """是否为模块项目"""

    item_key: Optional[str] = None
    """积分类型"""

    item_name: Optional[str] = None
    """项目名"""

    price: Optional[str] = None
    """项目 key 名"""

    related_module: Optional[str] = None
    """关联模块"""


class PointPriceRetrieveResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestWhitelist:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_filtering_data(self, client: Czlai) -> None:
        whitelist = client.whitelist.filtering_data()
        assert whitelist is None

    @parametrize
    def test_method_filtering_data_with_all_params(self, client: Czlai) -> None:
        whitelist = client.whitelist.filtering_data(
            filtering_data="filtering_data",
        )
        assert whitelist is None

    @parametrize
    def test_raw_response_filtering_data(self, client: Czlai) -> None:
        response = client.whitelist.with_raw_response.filtering_data()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        whitelist = response.parse()
        assert whitelist is None

    @parametrize
    def test_streaming_response_filtering_data(self, client: Czlai) -> None:
        with client.whitelist.with_streaming_response.filtering_data() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            whitelist = response.parse()
            assert whitelist is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_save_data(self, client: Czlai) -> None:
        whitelist = client.whitelist.save_data()
        assert whitelist is None

    @parametrize
    def test_method_save_data_with_all_params(self, client: Czlai) -> None:
        whitelist = client.whitelist.save_data(
            save_data=["string", "string", "string"],
        )
        assert whitelist is None

    @parametrize
    def test_raw_response_save_data(self, client: Czlai) -> None:
        response = client.whitelist.with_raw_response.save_data()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        whitelist = response.parse()
        assert whitelist is None

    @parametrize
    def test_streaming_response_save_data(self, client: Czlai) -> None:
        with client.whitelist.with_streaming_response.save_data() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            whitelist = response.parse()
            assert whitelist is None

        assert cast(Any, response.is_closed) is True


class TestAsyncWhitelist:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_filtering_data(self, async_client: AsyncCzlai) -> None:
        whitelist = await async_client.whitelist.filtering_data()
        assert whitelist is None

    @parametrize
    async def test_method_filtering_data_with_all_params(self, async_client: AsyncCzlai) -> None:
        whitelist = await async_client.whitelist.filtering_data(
            filtering_data="filtering_data",
        )
        assert whitelist is None

    @parametrize
    async def test_raw_response_filtering_data(self, async_client: AsyncCzlai) -> None:
        response = await async_client.whitelist.with_raw_response.filtering_data()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        whitelist = await response.parse()
        assert whitelist is None

    @parametrize
    async def test_streaming_response_filtering_data(self, async_client: AsyncCzlai) -> None:
        async with async_client.whitelist.with_streaming_response.filtering_data() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            whitelist = await response.parse()
            assert whitelist is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_save_data(self, async_client: AsyncCzlai) -> None:
        whitelist = await async_client.whitelist.save_data()
        assert whitelist is None

    @parametrize
    async def test_method_save_data_with_all_params(self, async_client: AsyncCzlai) -> None:
        whitelist = await async_client.whitelist.save_data(
            save_data=["string", "string", "string"],
        )
        assert whitelist is None

    @parametrize
    async def test_raw_response_save_data(self, async_client: AsyncCzlai) -> None:
        response = await async_client.whitelist.with_raw_response.save_data()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        whitelist = await response.parse()
        assert whitelist is None

    @parametrize
    async def test_streaming_response_save_data(self, async_client: AsyncCzlai) -> None:
        async with async_client.whitelist.with_streaming_response.save_data() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            whitelist = await response.parse()
            assert whitelist is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AICheckupSessionStartResponse", "Data"]


class Data(BaseModel):
    session_id: Optional[str] = None


class AICheckupSessionStartResponse(BaseModel):
    data: Optional[Data] = None

    message: Optional[str] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["AICheckupReportTaskParams"]


class AICheckupReportTaskParams(TypedDict, total=False):
    session_id: Required[str]
    """会话 id"""

    img_url: str
    """图片 url"""

    report_type: int
    """报告类型"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    aipic_report_params,
    aipic_options_params,
    aipic_question_params,
    aipic_validate_params,
    aipic_pic_result_params,
    aipic_report_task_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["AipicResource", "AsyncAipicResource"]


class AipicResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AipicResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AipicResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AipicResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AipicResourceWithStreamingResponse(self)

    def options(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        question: str | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题选项

        Args:
          pet_profile_id: 宠物档案 id

          question: 问题

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aipic/options",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "question": question,
                    "session_id": session_id,
                },
                aipic_options_params.AipicOptionsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def pic_result(
        self,
        *,
        img_belong: int | NotGiven = NOT_GIVEN,
        img_url: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片结果(流式)

        Args:
          img_belong: 图片归属(1:宠物体态分析、2:宠物表情分析)

          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aipic/pic-result",
            body=maybe_transform(
                {
                    "img_belong": img_belong,
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aipic_pic_result_params.AipicPicResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def question(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题(流式)

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aipic/question",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aipic_question_params.AipicQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report(
        self,
        *,
        session_id: str,
        img_url: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        sub_module_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          sub_module_type: 图片归属(1:宠物体态分析、2:宠物表情分析、3:牙齿分析)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aipic/report",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "sub_module_type": sub_module_type,
                },
                aipic_report_params.AipicReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report_task(
        self,
        *,
        session_id: str,
        img_url: str | NotGiven = NOT_GIVEN,
        report_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          img_url: 图片 url

          report_type: 报告类型

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aipic/report-task",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "img_url": img_url,
                    "report_type": report_type,
                },
                aipic_report_task_params.AipicReportTaskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def validate(
        self,
        *,
        answer: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        question: str | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        验证答案是否有效

        Args:
          answer: 用户回答

          pet_profile_id: 宠物档案 id

          question: 问题

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aipic/validate",
            body=maybe_transform(
                {
                    "answer": answer,
                    "pet_profile_id": pet_profile_id,
                    "question": question,
                    "session_id": session_id,
                },
                aipic_validate_params.AipicValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAipicResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAipicResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAipicResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAipicResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAipicResourceWithStreamingResponse(self)

    async def options(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        question: str | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题选项

        Args:
          pet_profile_id: 宠物档案 id

          question: 问题

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aipic/options",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "question": question,
                    "session_id": session_id,
                },
                aipic_options_params.AipicOptionsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def pic_result(
        self,
        *,
        img_belong: int | NotGiven = NOT_GIVEN,
        img_url: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片结果(流式)

        Args:
          img_belong: 图片归属(1:宠物体态分析、2:宠物表情分析)

          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aipic/pic-result",
            body=await async_maybe_transform(
                {
                    "img_belong": img_belong,
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aipic_pic_result_params.AipicPicResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def question(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题(流式)

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aipic/question",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aipic_question_params.AipicQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report(
        self,
        *,
        session_id: str,
        img_url: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        sub_module_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          sub_module_type: 图片归属(1:宠物体态分析、2:宠物表情分析、3:牙齿分析)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aipic/report",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "sub_module_type": sub_module_type,
                },
                aipic_report_params.AipicReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report_task(
        self,
        *,
        session_id: str,
        img_url: str | NotGiven = NOT_GIVEN,
        report_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          img_url: 图片 url

          report_type: 报告类型

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aipic/report-task",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "img_url": img_url,
                    "report_type": report_type,
                },
                aipic_report_task_params.AipicReportTaskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def validate(
        self,
        *,
        answer: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        question: str | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        验证答案是否有效

        Args:
          answer: 用户回答

          pet_profile_id: 宠物档案 id

          question: 问题

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aipic/validate",
            body=await async_maybe_transform(
                {
                    "answer": answer,
                    "pet_profile_id": pet_profile_id,
                    "question": question,
                    "session_id": session_id,
                },
                aipic_validate_params.AipicValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AipicResourceWithRawResponse:
    def __init__(self, aipic: AipicResource) -> None:
        self._aipic = aipic

        self.options = to_raw_response_wrapper(
            aipic.options,
        )
        self.pic_result = to_raw_response_wrapper(
            aipic.pic_result,
        )
        self.question = to_raw_response_wrapper(
            aipic.question,
        )
        self.report = to_raw_response_wrapper(
            aipic.report,
        )
        self.report_task = to_raw_response_wrapper(
            aipic.report_task,
        )
        self.validate = to_raw_response_wrapper(
            aipic.validate,
        )


class AsyncAipicResourceWithRawResponse:
    def __init__(self, aipic: AsyncAipicResource) -> None:
        self._aipic = aipic

        self.options = async_to_raw_response_wrapper(
            aipic.options,
        )
        self.pic_result = async_to_raw_response_wrapper(
            aipic.pic_result,
        )
        self.question = async_to_raw_response_wrapper(
            aipic.question,
        )
        self.report = async_to_raw_response_wrapper(
            aipic.report,
        )
        self.report_task = async_to_raw_response_wrapper(
            aipic.report_task,
        )
        self.validate = async_to_raw_response_wrapper(
            aipic.validate,
        )


class AipicResourceWithStreamingResponse:
    def __init__(self, aipic: AipicResource) -> None:
        self._aipic = aipic

        self.options = to_streamed_response_wrapper(
            aipic.options,
        )
        self.pic_result = to_streamed_response_wrapper(
            aipic.pic_result,
        )
        self.question = to_streamed_response_wrapper(
            aipic.question,
        )
        self.report = to_streamed_response_wrapper(
            aipic.report,
        )
        self.report_task = to_streamed_response_wrapper(
            aipic.report_task,
        )
        self.validate = to_streamed_response_wrapper(
            aipic.validate,
        )


class AsyncAipicResourceWithStreamingResponse:
    def __init__(self, aipic: AsyncAipicResource) -> None:
        self._aipic = aipic

        self.options = async_to_streamed_response_wrapper(
            aipic.options,
        )
        self.pic_result = async_to_streamed_response_wrapper(
            aipic.pic_result,
        )
        self.question = async_to_streamed_response_wrapper(
            aipic.question,
        )
        self.report = async_to_streamed_response_wrapper(
            aipic.report,
        )
        self.report_task = async_to_streamed_response_wrapper(
            aipic.report_task,
        )
        self.validate = async_to_streamed_response_wrapper(
            aipic.validate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import session_record_history_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["SessionRecordsResource", "AsyncSessionRecordsResource"]


class SessionRecordsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SessionRecordsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return SessionRecordsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SessionRecordsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return SessionRecordsResourceWithStreamingResponse(self)

    def history(
        self,
        *,
        content: str,
        module_type: int,
        role: str,
        session_id: str,
        content_type: int | NotGiven = NOT_GIVEN,
        stage: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        保存聊天记录

        Args:
          content: 内容

          module_type: 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          role: 角色, 取值为其中之一 ==>[user, ai]

          session_id: 会话 id

          content_type: 1-文字 2-图文

          stage: 1-用户主诉 2-用户回答 3-AI 提问 4-AI 病情小结 5-AI 病例报告 6-AI 输出 7-用户补充

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/session-record/history",
            body=maybe_transform(
                {
                    "content": content,
                    "module_type": module_type,
                    "role": role,
                    "session_id": session_id,
                    "content_type": content_type,
                    "stage": stage,
                },
                session_record_history_params.SessionRecordHistoryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncSessionRecordsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSessionRecordsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSessionRecordsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSessionRecordsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncSessionRecordsResourceWithStreamingResponse(self)

    async def history(
        self,
        *,
        content: str,
        module_type: int,
        role: str,
        session_id: str,
        content_type: int | NotGiven = NOT_GIVEN,
        stage: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        保存聊天记录

        Args:
          content: 内容

          module_type: 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          role: 角色, 取值为其中之一 ==>[user, ai]

          session_id: 会话 id

          content_type: 1-文字 2-图文

          stage: 1-用户主诉 2-用户回答 3-AI 提问 4-AI 病情小结 5-AI 病例报告 6-AI 输出 7-用户补充

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/session-record/history",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "module_type": module_type,
                    "role": role,
                    "session_id": session_id,
                    "content_type": content_type,
                    "stage": stage,
                },
                session_record_history_params.SessionRecordHistoryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SessionRecordsResourceWithRawResponse:
    def __init__(self, session_records: SessionRecordsResource) -> None:
        self._session_records = session_records

        self.history = to_raw_response_wrapper(
            session_records.history,
        )


class AsyncSessionRecordsResourceWithRawResponse:
    def __init__(self, session_records: AsyncSessionRecordsResource) -> None:
        self._session_records = session_records

        self.history = async_to_raw_response_wrapper(
            session_records.history,
        )


class SessionRecordsResourceWithStreamingResponse:
    def __init__(self, session_records: SessionRecordsResource) -> None:
        self._session_records = session_records

        self.history = to_streamed_response_wrapper(
            session_records.history,
        )


class AsyncSessionRecordsResourceWithStreamingResponse:
    def __init__(self, session_records: AsyncSessionRecordsResource) -> None:
        self._session_records = session_records

        self.history = async_to_streamed_response_wrapper(
            session_records.history,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    ai_checkup_report_params,
    ai_checkup_summary_params,
    ai_checkup_is_first_params,
    ai_checkup_question_params,
    ai_checkup_pic_result_params,
    ai_checkup_report_task_params,
    ai_checkup_update_profile_params,
    ai_checkup_question_result_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.ai_checkup_is_first_response import AICheckupIsFirstResponse
from ..types.ai_checkup_session_start_response import AICheckupSessionStartResponse
from ..types.ai_checkup_update_profile_response import AICheckupUpdateProfileResponse

__all__ = ["AICheckupResource", "AsyncAICheckupResource"]


class AICheckupResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AICheckupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AICheckupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AICheckupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AICheckupResourceWithStreamingResponse(self)

    def is_first(
        self,
        *,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AICheckupIsFirstResponse:
        """
        检查是否为当月首检

        Args:
          pet_profile_id: 宠物档案 ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/ai-checkup/is-first",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"pet_profile_id": pet_profile_id}, ai_checkup_is_first_params.AICheckupIsFirstParams
                ),
            ),
            cast_to=AICheckupIsFirstResponse,
        )

    def pic_result(
        self,
        *,
        img_url: str,
        pet_profile_id: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片结果

        Args:
          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-checkup/pic-result",
            body=maybe_transform(
                {
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_pic_result_params.AICheckupPicResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def question(
        self,
        *,
        pet_profile_id: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-checkup/question",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_question_params.AICheckupQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def question_result(
        self,
        *,
        index: int,
        pet_profile_id: int,
        question_id: str,
        round: str,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题

        Args:
          index: 宠物档案 id

          pet_profile_id: 宠物档案 id

          question_id: 回答 id

          round: 题目轮次

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-checkup/question-result",
            body=maybe_transform(
                {
                    "index": index,
                    "pet_profile_id": pet_profile_id,
                    "question_id": question_id,
                    "round": round,
                    "session_id": session_id,
                },
                ai_checkup_question_result_params.AICheckupQuestionResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report(
        self,
        *,
        pet_profile_id: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-checkup/report",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_report_params.AICheckupReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report_task(
        self,
        *,
        session_id: str,
        img_url: str | NotGiven = NOT_GIVEN,
        report_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          img_url: 图片 url

          report_type: 报告类型

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-checkup/report-task",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "img_url": img_url,
                    "report_type": report_type,
                },
                ai_checkup_report_task_params.AICheckupReportTaskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def session_start(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AICheckupSessionStartResponse:
        """开始一个新的会话"""
        return self._get(
            "/ai-checkup/session-start",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AICheckupSessionStartResponse,
        )

    def summary(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        生成总结

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._post(
            "/ai-checkup/summary",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_summary_params.AICheckupSummaryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def update_profile(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        update_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AICheckupUpdateProfileResponse:
        """
        更新宠物档案的体检参数

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          update_type: 更新类型, 可选 1,2,3

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/ai-checkup/update-profile",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                    "update_type": update_type,
                },
                ai_checkup_update_profile_params.AICheckupUpdateProfileParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AICheckupUpdateProfileResponse,
        )


class AsyncAICheckupResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAICheckupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAICheckupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAICheckupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAICheckupResourceWithStreamingResponse(self)

    async def is_first(
        self,
        *,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AICheckupIsFirstResponse:
        """
        检查是否为当月首检

        Args:
          pet_profile_id: 宠物档案 ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/ai-checkup/is-first",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"pet_profile_id": pet_profile_id}, ai_checkup_is_first_params.AICheckupIsFirstParams
                ),
            ),
            cast_to=AICheckupIsFirstResponse,
        )

    async def pic_result(
        self,
        *,
        img_url: str,
        pet_profile_id: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片结果

        Args:
          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-checkup/pic-result",
            body=await async_maybe_transform(
                {
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_pic_result_params.AICheckupPicResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def question(
        self,
        *,
        pet_profile_id: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-checkup/question",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_question_params.AICheckupQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def question_result(
        self,
        *,
        index: int,
        pet_profile_id: int,
        question_id: str,
        round: str,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题

        Args:
          index: 宠物档案 id

          pet_profile_id: 宠物档案 id

          question_id: 回答 id

          round: 题目轮次

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-checkup/question-result",
            body=await async_maybe_transform(
                {
                    "index": index,
                    "pet_profile_id": pet_profile_id,
                    "question_id": question_id,
                    "round": round,
                    "session_id": session_id,
                },
                ai_checkup_question_result_params.AICheckupQuestionResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report(
        self,
        *,
        pet_profile_id: int,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-checkup/report",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_report_params.AICheckupReportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report_task(
        self,
        *,
        session_id: str,
        img_url: str | NotGiven = NOT_GIVEN,
        report_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          img_url: 图片 url

          report_type: 报告类型

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-checkup/report-task",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "img_url": img_url,
                    "report_type": report_type,
                },
                ai_checkup_report_task_params.AICheckupReportTaskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def session_start(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AICheckupSessionStartResponse:
        """开始一个新的会话"""
        return await self._get(
            "/ai-checkup/session-start",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AICheckupSessionStartResponse,
        )

    async def summary(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        生成总结

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._post(
            "/ai-checkup/summary",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                ai_checkup_summary_params.AICheckupSummaryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def update_profile(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        update_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AICheckupUpdateProfileResponse:
        """
        更新宠物档案的体检参数

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          update_type: 更新类型, 可选 1,2,3

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/ai-checkup/update-profile",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                    "update_type": update_type,
                },
                ai_checkup_update_profile_params.AICheckupUpdateProfileParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AICheckupUpdateProfileResponse,
        )


class AICheckupResourceWithRawResponse:
    def __init__(self, ai_checkup: AICheckupResource) -> None:
        self._ai_checkup = ai_checkup

        self.is_first = to_raw_response_wrapper(
            ai_checkup.is_first,
        )
        self.pic_result = to_raw_response_wrapper(
            ai_checkup.pic_result,
        )
        self.question = to_raw_response_wrapper(
            ai_checkup.question,
        )
        self.question_result = to_raw_response_wrapper(
            ai_checkup.question_result,
        )
        self.report = to_raw_response_wrapper(
            ai_checkup.report,
        )
        self.report_task = to_raw_response_wrapper(
            ai_checkup.report_task,
        )
        self.session_start = to_raw_response_wrapper(
            ai_checkup.session_start,
        )
        self.summary = to_raw_response_wrapper(
            ai_checkup.summary,
        )
        self.update_profile = to_raw_response_wrapper(
            ai_checkup.update_profile,
        )


class AsyncAICheckupResourceWithRawResponse:
    def __init__(self, ai_checkup: AsyncAICheckupResource) -> None:
        self._ai_checkup = ai_checkup

        self.is_first = async_to_raw_response_wrapper(
            ai_checkup.is_first,
        )
        self.pic_result = async_to_raw_response_wrapper(
            ai_checkup.pic_result,
        )
        self.question = async_to_raw_response_wrapper(
            ai_checkup.question,
        )
        self.question_result = async_to_raw_response_wrapper(
            ai_checkup.question_result,
        )
        self.report = async_to_raw_response_wrapper(
            ai_checkup.report,
        )
        self.report_task = async_to_raw_response_wrapper(
            ai_checkup.report_task,
        )
        self.session_start = async_to_raw_response_wrapper(
            ai_checkup.session_start,
        )
        self.summary = async_to_raw_response_wrapper(
            ai_checkup.summary,
        )
        self.update_profile = async_to_raw_response_wrapper(
            ai_checkup.update_profile,
        )


class AICheckupResourceWithStreamingResponse:
    def __init__(self, ai_checkup: AICheckupResource) -> None:
        self._ai_checkup = ai_checkup

        self.is_first = to_streamed_response_wrapper(
            ai_checkup.is_first,
        )
        self.pic_result = to_streamed_response_wrapper(
            ai_checkup.pic_result,
        )
        self.question = to_streamed_response_wrapper(
            ai_checkup.question,
        )
        self.question_result = to_streamed_response_wrapper(
            ai_checkup.question_result,
        )
        self.report = to_streamed_response_wrapper(
            ai_checkup.report,
        )
        self.report_task = to_streamed_response_wrapper(
            ai_checkup.report_task,
        )
        self.session_start = to_streamed_response_wrapper(
            ai_checkup.session_start,
        )
        self.summary = to_streamed_response_wrapper(
            ai_checkup.summary,
        )
        self.update_profile = to_streamed_response_wrapper(
            ai_checkup.update_profile,
        )


class AsyncAICheckupResourceWithStreamingResponse:
    def __init__(self, ai_checkup: AsyncAICheckupResource) -> None:
        self._ai_checkup = ai_checkup

        self.is_first = async_to_streamed_response_wrapper(
            ai_checkup.is_first,
        )
        self.pic_result = async_to_streamed_response_wrapper(
            ai_checkup.pic_result,
        )
        self.question = async_to_streamed_response_wrapper(
            ai_checkup.question,
        )
        self.question_result = async_to_streamed_response_wrapper(
            ai_checkup.question_result,
        )
        self.report = async_to_streamed_response_wrapper(
            ai_checkup.report,
        )
        self.report_task = async_to_streamed_response_wrapper(
            ai_checkup.report_task,
        )
        self.session_start = async_to_streamed_response_wrapper(
            ai_checkup.session_start,
        )
        self.summary = async_to_streamed_response_wrapper(
            ai_checkup.summary,
        )
        self.update_profile = async_to_streamed_response_wrapper(
            ai_checkup.update_profile,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import (
    AICheckupIsFirstResponse,
    AICheckupSessionStartResponse,
    AICheckupUpdateProfileResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAICheckup:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_is_first(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.is_first(
            pet_profile_id=0,
        )
        assert_matches_type(AICheckupIsFirstResponse, ai_checkup, path=["response"])

    @parametrize
    def test_raw_response_is_first(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.is_first(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert_matches_type(AICheckupIsFirstResponse, ai_checkup, path=["response"])

    @parametrize
    def test_streaming_response_is_first(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.is_first(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert_matches_type(AICheckupIsFirstResponse, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_pic_result(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    def test_raw_response_pic_result(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert ai_checkup is None

    @parametrize
    def test_streaming_response_pic_result(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_question(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.question(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    def test_raw_response_question(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.question(
            pet_profile_id=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert ai_checkup is None

    @parametrize
    def test_streaming_response_question(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.question(
            pet_profile_id=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_question_result(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.question_result(
            index=0,
            pet_profile_id=0,
            question_id="question_id",
            round="round",
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    def test_raw_response_question_result(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.question_result(
            index=0,
            pet_profile_id=0,
            question_id="question_id",
            round="round",
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert ai_checkup is None

    @parametrize
    def test_streaming_response_question_result(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.question_result(
            index=0,
            pet_profile_id=0,
            question_id="question_id",
            round="round",
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.report(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    def test_raw_response_report(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.report(
            pet_profile_id=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert ai_checkup is None

    @parametrize
    def test_streaming_response_report(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.report(
            pet_profile_id=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report_task(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.report_task(
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    def test_method_report_task_with_all_params(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.report_task(
            session_id="session_id",
            img_url="img_url",
            report_type=0,
        )
        assert ai_checkup is None

    @parametrize
    def test_raw_response_report_task(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert ai_checkup is None

    @parametrize
    def test_streaming_response_report_task(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_session_start(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.session_start()
        assert_matches_type(AICheckupSessionStartResponse, ai_checkup, path=["response"])

    @parametrize
    def test_raw_response_session_start(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.session_start()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert_matches_type(AICheckupSessionStartResponse, ai_checkup, path=["response"])

    @parametrize
    def test_streaming_response_session_start(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.session_start() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert_matches_type(AICheckupSessionStartResponse, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_summary(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.summary()
        assert_matches_type(str, ai_checkup, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_summary_with_all_params(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.summary(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, ai_checkup, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_summary(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.summary()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert_matches_type(str, ai_checkup, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_summary(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.summary() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert_matches_type(str, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_update_profile(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.update_profile()
        assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

    @parametrize
    def test_method_update_profile_with_all_params(self, client: Czlai) -> None:
        ai_checkup = client.ai_checkup.update_profile(
            pet_profile_id=0,
            session_id="session_id",
            update_type=0,
        )
        assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

    @parametrize
    def test_raw_response_update_profile(self, client: Czlai) -> None:
        response = client.ai_checkup.with_raw_response.update_profile()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = response.parse()
        assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

    @parametrize
    def test_streaming_response_update_profile(self, client: Czlai) -> None:
        with client.ai_checkup.with_streaming_response.update_profile() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = response.parse()
            assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncAICheckup:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_is_first(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.is_first(
            pet_profile_id=0,
        )
        assert_matches_type(AICheckupIsFirstResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_raw_response_is_first(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.is_first(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert_matches_type(AICheckupIsFirstResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_streaming_response_is_first(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.is_first(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert_matches_type(AICheckupIsFirstResponse, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_pic_result(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    async def test_raw_response_pic_result(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert ai_checkup is None

    @parametrize
    async def test_streaming_response_pic_result(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_question(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.question(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    async def test_raw_response_question(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.question(
            pet_profile_id=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert ai_checkup is None

    @parametrize
    async def test_streaming_response_question(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.question(
            pet_profile_id=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_question_result(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.question_result(
            index=0,
            pet_profile_id=0,
            question_id="question_id",
            round="round",
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    async def test_raw_response_question_result(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.question_result(
            index=0,
            pet_profile_id=0,
            question_id="question_id",
            round="round",
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert ai_checkup is None

    @parametrize
    async def test_streaming_response_question_result(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.question_result(
            index=0,
            pet_profile_id=0,
            question_id="question_id",
            round="round",
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.report(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    async def test_raw_response_report(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.report(
            pet_profile_id=0,
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert ai_checkup is None

    @parametrize
    async def test_streaming_response_report(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.report(
            pet_profile_id=0,
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report_task(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.report_task(
            session_id="session_id",
        )
        assert ai_checkup is None

    @parametrize
    async def test_method_report_task_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.report_task(
            session_id="session_id",
            img_url="img_url",
            report_type=0,
        )
        assert ai_checkup is None

    @parametrize
    async def test_raw_response_report_task(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert ai_checkup is None

    @parametrize
    async def test_streaming_response_report_task(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert ai_checkup is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_session_start(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.session_start()
        assert_matches_type(AICheckupSessionStartResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_raw_response_session_start(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.session_start()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert_matches_type(AICheckupSessionStartResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_streaming_response_session_start(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.session_start() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert_matches_type(AICheckupSessionStartResponse, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_summary(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.summary()
        assert_matches_type(str, ai_checkup, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_summary_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.summary(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, ai_checkup, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_summary(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.summary()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert_matches_type(str, ai_checkup, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_summary(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.summary() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert_matches_type(str, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_update_profile(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.update_profile()
        assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_method_update_profile_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_checkup = await async_client.ai_checkup.update_profile(
            pet_profile_id=0,
            session_id="session_id",
            update_type=0,
        )
        assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_raw_response_update_profile(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_checkup.with_raw_response.update_profile()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_checkup = await response.parse()
        assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

    @parametrize
    async def test_streaming_response_update_profile(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_checkup.with_streaming_response.update_profile() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_checkup = await response.parse()
            assert_matches_type(AICheckupUpdateProfileResponse, ai_checkup, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["MedicalRecordUpdateParams"]


class MedicalRecordUpdateParams(TypedDict, total=False):
    is_read: int

    report_id: int
    """医疗报告 ID"""

    report_time: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    stage: str
    """阶段存档"""

    status: int
    """1-进行中 2-已完成 3-手动结束 4-自动结束"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import ai_trial_options_params, ai_trial_question_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["AITrialsResource", "AsyncAITrialsResource"]


class AITrialsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AITrialsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AITrialsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AITrialsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AITrialsResourceWithStreamingResponse(self)

    def options(
        self,
        *,
        question: str | NotGiven = NOT_GIVEN,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题选项

        Args:
          question: 问题

          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/options",
            body=maybe_transform(
                {
                    "question": question,
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_options_params.AITrialOptionsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def question(
        self,
        *,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题(流式)

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-trial/question",
            body=maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_question_params.AITrialQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAITrialsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAITrialsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAITrialsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAITrialsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAITrialsResourceWithStreamingResponse(self)

    async def options(
        self,
        *,
        question: str | NotGiven = NOT_GIVEN,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题选项

        Args:
          question: 问题

          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/options",
            body=await async_maybe_transform(
                {
                    "question": question,
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_options_params.AITrialOptionsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def question(
        self,
        *,
        service_type: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取问题(流式)

        Args:
          service_type: 1-猫狗 2-异宠

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-trial/question",
            body=await async_maybe_transform(
                {
                    "service_type": service_type,
                    "session_id": session_id,
                },
                ai_trial_question_params.AITrialQuestionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AITrialsResourceWithRawResponse:
    def __init__(self, ai_trials: AITrialsResource) -> None:
        self._ai_trials = ai_trials

        self.options = to_raw_response_wrapper(
            ai_trials.options,
        )
        self.question = to_raw_response_wrapper(
            ai_trials.question,
        )


class AsyncAITrialsResourceWithRawResponse:
    def __init__(self, ai_trials: AsyncAITrialsResource) -> None:
        self._ai_trials = ai_trials

        self.options = async_to_raw_response_wrapper(
            ai_trials.options,
        )
        self.question = async_to_raw_response_wrapper(
            ai_trials.question,
        )


class AITrialsResourceWithStreamingResponse:
    def __init__(self, ai_trials: AITrialsResource) -> None:
        self._ai_trials = ai_trials

        self.options = to_streamed_response_wrapper(
            ai_trials.options,
        )
        self.question = to_streamed_response_wrapper(
            ai_trials.question,
        )


class AsyncAITrialsResourceWithStreamingResponse:
    def __init__(self, ai_trials: AsyncAITrialsResource) -> None:
        self._ai_trials = ai_trials

        self.options = async_to_streamed_response_wrapper(
            ai_trials.options,
        )
        self.question = async_to_streamed_response_wrapper(
            ai_trials.question,
        )
